@@ -5,9 +5,12 @@ License: GPL-3.0 License
 
 import ctypes
 import faulthandler
+import os
+import tempfile
 from ctypes import POINTER, c_int, c_uint, c_uint8, c_void_p, cast, create_string_buffer
 
 from reversebox.common.common import get_dll_path
+from reversebox.common.constants import DLL_LOG_FILE_NAME
 from reversebox.common.logger import get_logger
 from reversebox.image.image_formats import ImageFormats
 
@@ -88,7 +91,8 @@ class PvrTexlibImageDecoderEncoder:
     """
 
     def __init__(self):
-        faulthandler.enable()
+        with open(os.path.join(tempfile.gettempdir(), DLL_LOG_FILE_NAME), "a", encoding="utf-8") as f:
+            faulthandler.enable(f)
 
     def _get_pvrtexlib_format_number(self, image_format: ImageFormats) -> int:
         """
