@@ -172,6 +172,18 @@ class ImageDecoder:
         p[3] = (0x00 if a == 0 else 0xFF)
         return p
 
+    def _decode_bgra5551_tzar_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        b = pixel_int & 0x1F
+        g = (pixel_int >> 5) & 0x1F
+        r = (pixel_int >> 10) & 0x1F
+
+        p[0] = (r << 3) | (r >> 2)
+        p[1] = (g << 3) | (g >> 2)
+        p[2] = (b << 3) | (b >> 2)
+        p[3] = (0x00 if pixel_int == 0x6F else 0xFF)
+        return p
+
     def _decode_rgbx5551_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
         r = pixel_int & 0x1F
@@ -202,6 +214,25 @@ class ImageDecoder:
         p[3] = a
         return p
 
+    def _decode_bgrt5551_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        b = pixel_int & 0x1F
+        g = (pixel_int >> 5) & 0x1F
+        r = (pixel_int >> 10) & 0x1F
+        p[0] = (r << 3) | (r >> 2)
+        p[1] = (g << 3) | (g >> 2)
+        p[2] = (b << 3) | (b >> 2)
+
+        if pixel_int & 0x8000:  # translucient
+            a = 0x80
+        elif pixel_int == 0:  # transparent
+            a = 0x00
+        else:  # opaque
+            a = 0xFF
+
+        p[3] = a
+        return p
+
     def _decode_rgba5551_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
         r = pixel_int & 0x1F
@@ -310,6 +341,21 @@ class ImageDecoder:
         p[3] = 0xFF
         return p
 
+    def _decode_bgrt8888_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        p[0] = (pixel_int >> 16) & 0xFF
+        p[1] = (pixel_int >> 8) & 0xFF
+        p[2] = (pixel_int >> 0) & 0xFF
+        if pixel_int & 0x8000:  # translucient
+            a = 0x80
+        elif pixel_int == 0:  # transparent
+            a = 0x00
+        else:  # opaque
+            a = 0xFF
+
+        p[3] = a
+        return p
+
     # TODO - fix this, not decoding properly
     def _decode_rgbm8888_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
@@ -342,6 +388,20 @@ class ImageDecoder:
         p[3] = (pixel_int >> 24) & 0xff
         return p
 
+    def _decode_bgra8888_tzar_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        p[0] = (pixel_int >> 16) & 0xff
+        p[1] = (pixel_int >> 8) & 0xff
+        p[2] = (pixel_int >> 0) & 0xff
+
+        if pixel_int == 0x6F:  # transparent
+            a = 0x00
+        else:  # opaque
+            a = 0xFF
+
+        p[3] = a
+        return p
+
     def _decode_abgr8888_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
         p[0] = (pixel_int >> 24) & 0xff
@@ -443,6 +503,23 @@ class ImageDecoder:
         p[3] = (a << 4) | (a >> 0)
         return p
 
+    def _decode_bgra4444_leapster_pixel(self, pixel_int: int) -> bytes:
+        p = bytearray(4)
+        b = (pixel_int >> 0) & 0x0f
+        g = (pixel_int >> 4) & 0x0f
+        r = (pixel_int >> 8) & 0x0f
+
+        if pixel_int == 0xF0:
+            a = 0x00
+        else:
+            a = 0xFF
+
+        p[0] = (r << 4) | (r >> 0)
+        p[1] = (g << 4) | (g >> 0)
+        p[2] = (b << 4) | (b >> 0)
+        p[3] = a
+        return p
+
     def _decode_rgbx4444_pixel(self, pixel_int: int) -> bytes:
         p = bytearray(4)
         r = (pixel_int >> 0) & 0x0f
@@ -598,8 +675,10 @@ class ImageDecoder:
         ImageFormats.BGR565: (_decode_bgr565_pixel, 16, get_uint16),
         ImageFormats.RGBX5551: (_decode_rgbx5551_pixel, 16, get_uint16),
         ImageFormats.RGBT5551: (_decode_rgbt5551_pixel, 16, get_uint16),
+        ImageFormats.BGRT5551: (_decode_bgrt5551_pixel, 16, get_uint16),
         ImageFormats.RGBA5551: (_decode_rgba5551_pixel, 16, get_uint16),
         ImageFormats.BGRA5551: (_decode_bgra5551_pixel, 16, get_uint16),
+        ImageFormats.BGRA5551_TZAR: (_decode_bgra5551_tzar_pixel, 16, get_uint16),
         ImageFormats.BGRX5551: (_decode_bgrx5551_pixel, 16, get_uint16),
         ImageFormats.RGBA4444: (_decode_rgba4444_pixel, 16, get_uint16),
         ImageFormats.ARGB4444: (_decode_argb4444_pixel, 16, get_uint16),
@@ -608,6 +687,7 @@ class ImageDecoder:
         ImageFormats.XBGR4444: (_decode_xbgr4444_pixel, 16, get_uint16),
         ImageFormats.RGBX4444: (_decode_rgbx4444_pixel, 16, get_uint16),  # RGB444
         ImageFormats.BGRA4444: (_decode_bgra4444_pixel, 16, get_uint16),  # BGR444
+        ImageFormats.BGRA4444_LEAPSTER: (_decode_bgra4444_leapster_pixel, 16, get_uint16),
         ImageFormats.BGRX4444: (_decode_bgrx4444_pixel, 16, get_uint16),  # BGR444
         ImageFormats.XRGB1555: (_decode_xrgb1555_pixel, 16, get_uint16),  # RGB555
         ImageFormats.XBGR1555: (_decode_xbgr1555_pixel, 16, get_uint16),  # BGR555
@@ -628,9 +708,11 @@ class ImageDecoder:
         ImageFormats.ABGR8888: (_decode_abgr8888_pixel, 32, get_uint32),
         ImageFormats.RGBA8888: (_decode_rgba8888_pixel, 32, get_uint32),
         ImageFormats.BGRA8888: (_decode_bgra8888_pixel, 32, get_uint32),
+        ImageFormats.BGRA8888_TZAR: (_decode_bgra8888_tzar_pixel, 32, get_uint32),
         ImageFormats.XRGB8888: (_decode_xrgb8888_pixel, 32, get_uint32),
         ImageFormats.RGBX8888: (_decode_rgbx8888_pixel, 32, get_uint32),
         ImageFormats.BGRX8888: (_decode_bgrx8888_pixel, 32, get_uint32),
+        ImageFormats.BGRT8888: (_decode_bgrt8888_pixel, 32, get_uint32),
         ImageFormats.RGBM8888: (_decode_rgbm8888_pixel, 32, get_uint32),
         ImageFormats.R32: (_decode_r_only_pixel, 32, get_uint32),
         ImageFormats.G32: (_decode_g_only_pixel, 32, get_uint32),
@@ -644,6 +726,7 @@ class ImageDecoder:
         # image_format: bits_per_pixel
         ImageFormats.PAL4: 4,
         ImageFormats.PAL8: 8,
+        ImageFormats.PAL8_TZAR: 8,
         ImageFormats.PAL16: 16,
         ImageFormats.PAL_I8A8: 16,
         ImageFormats.PAL32: 32,
@@ -755,7 +838,10 @@ class ImageDecoder:
             for i in range(img_width * img_height):
                 palette_index: bytes = image_handler.get_bytes(image_offset, 1)
                 palette_index_int: int = struct.unpack(image_endianess_format + "B", palette_index or b'\x00')[0]
-                texture_data[i * 4:(i + 1) * 4] = decode_function(self, palette_data_ints[palette_index_int])  # noqa
+                if image_format is ImageFormats.PAL8_TZAR and palette_index_int == 0x6F:
+                    texture_data[i * 4:(i + 1) * 4] = decode_function(self, palette_index_int)  # noqa
+                else:
+                    texture_data[i * 4:(i + 1) * 4] = decode_function(self, palette_data_ints[palette_index_int])  # noqa
                 image_offset += 1
         elif img_bits_per_pixel == 16:  # e.g. PAL16
             for i in range(img_width * img_height):
